#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-rename-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-rename-plugin-2.3.0.0-8f4ImCAPa6KLdVeWcUQNNm
key:                  hls-rename-plugin-2.3.0.0-8f4ImCAPa6KLdVeWcUQNNm
license:              Apache-2.0
maintainer:           madine.oliver@gmail.com
author:               Oliver Madine
synopsis:             Rename plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  4b61313b312d76d0adaadba82543ff1f
exposed:              True
exposed-modules:      Ide.Plugin.Rename
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-rename-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-rename-plugin
hs-libraries:         HShls-rename-plugin-2.3.0.0-8f4ImCAPa6KLdVeWcUQNNm
depends:
    base-4.18.2.1 containers-0.6.7 extra-1.7.16-5TJRL61mQdJ37nJ79jr8U
    ghc-9.6.6 ghc-exactprint-1.7.1.0-Fp2lI202tnf3a5KLwE8APN
    ghcide-2.3.0.0-78iRkwjTMmGGIR2bvJufIi
    hashable-1.4.7.0-AuDVFqXH7XaG9xiVOVTNBi
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-I2TIZPLmsU77RUeBojIIkv
    hls-plugin-api-2.3.0.0-PV4VuNiiei50o1roJRQC9
    hls-refactor-plugin-2.3.0.0-1K6aG51WmyTEmm3SwhLX7V
    lens-5.3.4-CugvPwDQfTKJtJ2DRsVKfV
    lsp-2.2.0.0-ASJx8lMy3AeIMffE9ZbIv9
    lsp-types-2.0.2.0-9I6W00SGQct8ofSsEutf7C
    mod-0.2.1.0-5lMrcX6NjVn4QI8bsAgLsi mtl-2.3.1
    syb-0.7.3-IWvKvWWONKwAx7053zcTAl text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-IS42DvcTPVH3F2RDVwits

haddock-interfaces:
    /usr/share/doc/haskell-hls-rename-plugin/html/hls-rename-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-rename-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

